==> cscec5b-fbxt-api-3.0.1-20220228.021628-49-sources.jar: com/ejianc/business/fbxt/odd/vo/sysupl/OddApplyRequest.java <==
package com.ejianc.business.fbxt.odd.vo.sysupl;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

public class OddApplyRequest {
    private static final long serialVersionUID = 1L;
    private Long pkOddApply;
    private String oddCode;
    private String pkOrg;
    private String pkProject;
    private String projectName;
    private String pkContract;
    private String contractName;
    private String contractCode;
    private String pkSupplier;
    private String supplierName;
    private String createDate;
    private Integer oddType;
    private Integer belong;
    private String oddDesc;
    private String memo; // 备注
    private String pkUser;
    private String name;
    private Integer oddStatus;
    private Integer oddInfoStatus;
    private List<OddInfoApply> oddInfoList;
    private Integer pkStep;
    private String stepVersion;
    private Integer nextIndex;
    private String stepPkUser;
    private String userName; // 审批人名字
    private String text;
    private String beginTime;
    private String endTime;
    private String describe;
    private String pkContractRedirect;
    private BigDecimal pricesum;//总价
    private BigDecimal sumcheck;//审核总价
    private BigDecimal sumredirect;//转扣总价
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date ts;
    private List<String> pkList;
    /**
     * 是否被引用，0-否，1-是
     */
    private Integer isused;
    /**
     * 用工单主键
     */
    private Long pkOdd;
    /**
     * 经办人
     */
    private String manager;
    /**
     * 经办人姓名
     */
    private String managname;
    /**
     * 意见
     */
    private String opinion;
    //原始附件
    private List<FileRelation> gzfileList;
    // 补充附件
    private List<FileRelation> bcfileList;
    //系统标识，广东公司为"gd";河南公司为"hn"
    private String sysmark;
    /**
     * 是否转扣，0-否，1-是
     */
    private Integer isredirect;
    /**
     * 施工部位
     */
    private String location;


    public Long getPkOddApply() {
        return pkOddApply;
    }

    public void setPkOddApply(Long pkOddApply) {
        this.pkOddApply = pkOddApply;
    }

    public String getOddCode() {
        return oddCode;
    }

    public void setOddCode(String oddCode) {
        this.oddCode = oddCode;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getCreateDate() {
        return createDate;
    }

    public void setCreateDate(String createDate) {
        this.createDate = createDate;
    }

    public Integer getOddType() {
        return oddType;
    }

    public void setOddType(Integer oddType) {
        this.oddType = oddType;
    }

    public Integer getBelong() {
        return belong;
    }

    public void setBelong(Integer belong) {
        this.belong = belong;
    }

    public String getOddDesc() {
        return oddDesc;
    }

    public void setOddDesc(String oddDesc) {
        this.oddDesc = oddDesc;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getPkUser() {
        return pkUser;
    }

    public void setPkUser(String pkUser) {
        this.pkUser = pkUser;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getOddStatus() {
        return oddStatus;
    }

    public void setOddStatus(Integer oddStatus) {
        this.oddStatus = oddStatus;
    }

    public Integer getOddInfoStatus() {
        return oddInfoStatus;
    }

    public void setOddInfoStatus(Integer oddInfoStatus) {
        this.oddInfoStatus = oddInfoStatus;
    }

    public List<OddInfoApply> getOddInfoList() {
        return oddInfoList;
    }

    public void setOddInfoList(List<OddInfoApply> oddInfoList) {
        this.oddInfoList = oddInfoList;
    }

    public Integer getPkStep() {
        return pkStep;
    }

    public void setPkStep(Integer pkStep) {
        this.pkStep = pkStep;
    }

    public String getStepVersion() {
        return stepVersion;
    }

    public void setStepVersion(String stepVersion) {
        this.stepVersion = stepVersion;
    }

    public Integer getNextIndex() {
        return nextIndex;
    }

    public void setNextIndex(Integer nextIndex) {
        this.nextIndex = nextIndex;
    }

    public String getStepPkUser() {
        return stepPkUser;
    }

    public void setStepPkUser(String stepPkUser) {
        this.stepPkUser = stepPkUser;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getDescribe() {
        return describe;
    }

    public void setDescribe(String describe) {
        this.describe = describe;
    }

    public String getPkContractRedirect() {
        return pkContractRedirect;
    }

    public void setPkContractRedirect(String pkContractRedirect) {
        this.pkContractRedirect = pkContractRedirect;
    }

    public BigDecimal getPricesum() {
        return pricesum;
    }

    public void setPricesum(BigDecimal pricesum) {
        this.pricesum = pricesum;
    }

    public BigDecimal getSumcheck() {
        return sumcheck;
    }

    public void setSumcheck(BigDecimal sumcheck) {
        this.sumcheck = sumcheck;
    }

    public BigDecimal getSumredirect() {
        return sumredirect;
    }

    public void setSumredirect(BigDecimal sumredirect) {
        this.sumredirect = sumredirect;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public List<String> getPkList() {
        return pkList;
    }

    public void setPkList(List<String> pkList) {
        this.pkList = pkList;
    }

    public Integer getIsused() {
        return isused;
    }

    public void setIsused(Integer isused) {
        this.isused = isused;
    }

    public Long getPkOdd() {
        return pkOdd;
    }

    public void setPkOdd(Long pkOdd) {
        this.pkOdd = pkOdd;
    }

    public String getManager() {
        return manager;
    }

    public void setManager(String manager) {
        this.manager = manager;
    }

    public String getManagname() {
        return managname;
    }

    public void setManagname(String managname) {
        this.managname = managname;
    }

    public String getOpinion() {
        return opinion;
    }

    public void setOpinion(String opinion) {
        this.opinion = opinion;
    }

    public List<FileRelation> getGzfileList() {
        return gzfileList;
    }

    public void setGzfileList(List<FileRelation> gzfileList) {
        this.gzfileList = gzfileList;
    }

    public List<FileRelation> getBcfileList() {
        return bcfileList;
    }

    public void setBcfileList(List<FileRelation> bcfileList) {
        this.bcfileList = bcfileList;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public Integer getIsredirect() {
        return isredirect;
    }

    public void setIsredirect(Integer isredirect) {
        this.isredirect = isredirect;
    }

    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }
}

==> cscec5b-fbxt-api-3.0.1-20240221.074023-183-sources.jar: com/ejianc/business/fbxt/odd/vo/sysupl/OddApplyRequest.java <==
package com.ejianc.business.fbxt.odd.vo.sysupl;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

public class OddApplyRequest {
    private static final long serialVersionUID = 1L;
    private Long pkOddApply;
    private String oddCode;
    private String pkOrg;
    private String pkProject;
    private String projectName;
    private String pkContract;
    private String contractName;
    private String contractCode;
    private String pkSupplier;
    private String supplierName;
    private String createDate;
    private Integer oddType;
    private Integer belong;
    private String oddDesc;
    private String memo; // 备注
    private String pkUser;
    private String name;
    private Integer oddStatus;
    private Integer oddInfoStatus;
    private List<OddInfoApply> oddInfoList;
    private Integer pkStep;
    private String stepVersion;
    private Integer nextIndex;
    private String stepPkUser;
    private String userName; // 审批人名字
    private String text;
    private String beginTime;
    private String endTime;
    private String describe;
    private String pkContractRedirect;
    private BigDecimal pricesum;//总价
    private BigDecimal sumcheck;//审核总价
    private BigDecimal sumredirect;//转扣总价
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date ts;
    private List<String> pkList;
    /**
     * 是否被引用，0-否，1-是
     */
    private Integer isused;
    /**
     * 用工单主键
     */
    private Long pkOdd;
    /**
     * 经办人
     */
    private String manager;
    /**
     * 经办人姓名
     */
    private String managname;
    /**
     * 意见
     */
    private String opinion;
    //原始附件
    private List<FileRelation> gzfileList;
    // 补充附件
    private List<FileRelation> bcfileList;
    //系统标识，广东公司为"gd";河南公司为"hn"
    private String sysmark;
    /**
     * 是否转扣，0-否，1-是
     */
    private Integer isredirect;
    /**
     * 施工部位
     */
    private String location;

    private Long corpId; // 项目所属组织id
    private String corpName; // 项目所属组织名称
    private String corpSourceId; // 项目所属组织来源id

    public Long getCorpId() {
        return corpId;
    }

    public void setCorpId(Long corpId) {
        this.corpId = corpId;
    }

    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }

    public String getCorpSourceId() {
        return corpSourceId;
    }

    public void setCorpSourceId(String corpSourceId) {
        this.corpSourceId = corpSourceId;
    }

    public Long getPkOddApply() {
        return pkOddApply;
    }

    public void setPkOddApply(Long pkOddApply) {
        this.pkOddApply = pkOddApply;
    }

    public String getOddCode() {
        return oddCode;
    }

    public void setOddCode(String oddCode) {
        this.oddCode = oddCode;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getCreateDate() {
        return createDate;
    }

    public void setCreateDate(String createDate) {
        this.createDate = createDate;
    }

    public Integer getOddType() {
        return oddType;
    }

    public void setOddType(Integer oddType) {
        this.oddType = oddType;
    }

    public Integer getBelong() {
        return belong;
    }

    public void setBelong(Integer belong) {
        this.belong = belong;
    }

    public String getOddDesc() {
        return oddDesc;
    }

    public void setOddDesc(String oddDesc) {
        this.oddDesc = oddDesc;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getPkUser() {
        return pkUser;
    }

    public void setPkUser(String pkUser) {
        this.pkUser = pkUser;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getOddStatus() {
        return oddStatus;
    }

    public void setOddStatus(Integer oddStatus) {
        this.oddStatus = oddStatus;
    }

    public Integer getOddInfoStatus() {
        return oddInfoStatus;
    }

    public void setOddInfoStatus(Integer oddInfoStatus) {
        this.oddInfoStatus = oddInfoStatus;
    }

    public List<OddInfoApply> getOddInfoList() {
        return oddInfoList;
    }

    public void setOddInfoList(List<OddInfoApply> oddInfoList) {
        this.oddInfoList = oddInfoList;
    }

    public Integer getPkStep() {
        return pkStep;
    }

    public void setPkStep(Integer pkStep) {
        this.pkStep = pkStep;
    }

    public String getStepVersion() {
        return stepVersion;
    }

    public void setStepVersion(String stepVersion) {
        this.stepVersion = stepVersion;
    }

    public Integer getNextIndex() {
        return nextIndex;
    }

    public void setNextIndex(Integer nextIndex) {
        this.nextIndex = nextIndex;
    }

    public String getStepPkUser() {
        return stepPkUser;
    }

    public void setStepPkUser(String stepPkUser) {
        this.stepPkUser = stepPkUser;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getDescribe() {
        return describe;
    }

    public void setDescribe(String describe) {
        this.describe = describe;
    }

    public String getPkContractRedirect() {
        return pkContractRedirect;
    }

    public void setPkContractRedirect(String pkContractRedirect) {
        this.pkContractRedirect = pkContractRedirect;
    }

    public BigDecimal getPricesum() {
        return pricesum;
    }

    public void setPricesum(BigDecimal pricesum) {
        this.pricesum = pricesum;
    }

    public BigDecimal getSumcheck() {
        return sumcheck;
    }

    public void setSumcheck(BigDecimal sumcheck) {
        this.sumcheck = sumcheck;
    }

    public BigDecimal getSumredirect() {
        return sumredirect;
    }

    public void setSumredirect(BigDecimal sumredirect) {
        this.sumredirect = sumredirect;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public List<String> getPkList() {
        return pkList;
    }

    public void setPkList(List<String> pkList) {
        this.pkList = pkList;
    }

    public Integer getIsused() {
        return isused;
    }

    public void setIsused(Integer isused) {
        this.isused = isused;
    }

    public Long getPkOdd() {
        return pkOdd;
    }

    public void setPkOdd(Long pkOdd) {
        this.pkOdd = pkOdd;
    }

    public String getManager() {
        return manager;
    }

    public void setManager(String manager) {
        this.manager = manager;
    }

    public String getManagname() {
        return managname;
    }

    public void setManagname(String managname) {
        this.managname = managname;
    }

    public String getOpinion() {
        return opinion;
    }

    public void setOpinion(String opinion) {
        this.opinion = opinion;
    }

    public List<FileRelation> getGzfileList() {
        return gzfileList;
    }

    public void setGzfileList(List<FileRelation> gzfileList) {
        this.gzfileList = gzfileList;
    }

    public List<FileRelation> getBcfileList() {
        return bcfileList;
    }

    public void setBcfileList(List<FileRelation> bcfileList) {
        this.bcfileList = bcfileList;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public Integer getIsredirect() {
        return isredirect;
    }

    public void setIsredirect(Integer isredirect) {
        this.isredirect = isredirect;
    }

    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }
}
